NotFoundKind

Enum NotFoundKind 

#[non_exhaustive]
pub enum NotFoundKind { Commit, Ref, Branch, Tag, Remote, Path, Worktree, Submodule, }
The kind of named object that was not found.

Marked #[non_exhaustive] — new variants may be added in minor releases.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Commit



Ref



Branch



Tag



Remote



Path



Worktree



Submodule